@@ -1,5 +1,5 @@
 from FreeTAKServer.controllers.configuration.MainConfig import MainConfig
-from FreeTAKServer.controllers.configuration.types import Types
+from FreeTAKServer.controllers.configuration.Types import Types
 from FreeTAKServer.controllers.services.federation.handlers import StopHandler, DisconnectHandler, ConnectHandler, SendDataHandler, SendConnectionDataHandler, SendDisconnectionDataHandler
 from FreeTAKServer.model.protobufModel.fig_pb2 import FederatedEvent
 from FreeTAKServer.controllers.services.service_abstracts import ServerServiceInterface, ServiceBase
@@ -80,7 +80,7 @@ class FederationServerService(ServerServiceInterface, ServiceBase):
         self.m_SendConnectionHandler.setNextHandler(self.m_SendDisconnectionHandler)
 
     def main(self):
-        from lxml import etree
+        from defusedxml import ElementTree as etree
         while True:
             time.sleep(0.1)
             command = self.receive_command_data(self.pipe)
@@ -198,7 +198,7 @@ class FederationServerService(ServerServiceInterface, ServiceBase):
         return contentlength.to_bytes(4, byteorder="big")
 
     def send_data_to_clients(self, data):
-        from lxml import etree
+        from defusedxml import ElementTree as etree
         try:
             if self.federates:
                 xmlstring = data.xmlString
